*****************************************************************************************************
* Beyond tradition? How gender ideology impacts employment and family arrangements in Swiss couples
* Analyses 
*****************************************************************************************************

/* 
Preliminary information:

This stata syntax allows to reproduce the analyses included in the following article (and related online appendix):
Bornatici, C., & Zinn, I. (2025). Beyond tradition? How gender ideology impacts employment and family arrangements in Swiss couples. Gender & Society.

The data and documentation files are available from the platform SWISSUbase:
Swiss Household Panel (2022). Living in Switzerland waves 1-22 (V5.1.0) [Dataset]. FORS – Swiss Centre of Expertise in the Social Sciences. http://doi.org/10.48573/1nav-wy98.

Code author: Christina Bornatici, FORS – Swiss Centre of Expertise in the Social Sciences, University of Lausanne, Switzerland

After downloading the data, adapt the paths (below, and in each syntax) and run the syntaxes one after the other (i.e., Data_management_1 Data_management_2 Data_management_3 Data_management_4 Data_analysis_1) to replicate the results.
*/

// Set paths (to adapt)
global shpdata    	C:\Users\Data_original_file
global mydata 		C:\Users\Data_worked_file
global mylogfiles	C:\Users\Log files
global myanalyses	C:\Users\Data_analysis
global mygraphs		C:\Users\Graphs

version 17 // commands may vary between versions
set more off  // tells Stata not to pause after each page

capture log close // closes log file if any is open
log using "$mylogfiles\Analyses3.smcl", replace

use "${mydata}\shp_couple_hetero_1864_all_variables", clear 


*--------------------------------------------------------------------------------------
**# Descriptive statistics
*--------------------------------------------------------------------------------------
*Sample
//couples with complete information
cap drop nonmiss
gen nonmiss= !missing(work42_8h_2cat, hwcc60_perc_2cat, gatc7_4, famphase, edu_c2cat, inc_perc_2cat2mi, wave)
tab nonmiss, mi
//declare longitudinal data
xtset idcouple year 
xtdes if nonmiss==1

*In method section: Data and sample
// years included
tab year if nonmiss==1
// age
sum age age_p if nonmiss==1
// number of observations
tab nonmiss, mi //or: sum idcouple if nonmiss==1
//number of couples
cap drop first_c 
sort nonmiss idcouple year 
bysort nonmiss idcouple :  gen first_c=_n==1 // flag variable for first participation (specific sample)
lab var first_c "First participation of the couple in the SHP"
tab first_c if nonmiss==1
//number of observations per couple
cap drop nans_c
sort nonmiss idcouple
bysort nonmiss idcouple :  gen nans_c=_N	
lab var nans_c "Number of participations of the couple in our specific sample"
tab nans_c  if nonmiss==1 & first_c==1


*In method section: Dependent variables
//statistics for weekly hours in paid and unpaid work by gender
tabstat workhours42 workhours42_p hwhours60 hwhours60_p if nonmiss==1, s(n min max p50 iqr) col(stat)


*In method section: Couple's gender ideology
// low Cronbach's alphas
//women
alpha gat_workm_rev gat_ind if nonmiss==1 // continuous 
alpha gat_ind_str10_01 gat_workm_rev_str7_01 if nonmiss==1 // threshold at 10 for attitudes toward women's employment; threshold at 7 for attitudes toward maternal employment
//men
alpha gat_workm_rev_p gat_ind_p if nonmiss==1 // continuous 
alpha gat_ind_str10_01_p gat_workm_rev_str7_01_p if nonmiss==1 // threshold at 10 for attitudes toward women's employment; threshold at 7 for attitudes toward maternal employment
//couples
alpha gatc_ind_4 gatc7_4 if nonmiss==1 // threshold at 10 for attitudes toward women's employment; threshold at 7 for attitudes toward maternal employment


*In results section: undoing gender with alternative dependant variables
tab1 work42_2cat hw60_perc_2cat cct_perc_2cat  if nonmiss==1 


*TABLE 1: Descriptive Statistics, N= 16,072 Observations

set scheme plotplainblind // general scheme for graphs

tab1 work42_8h_2cat hwcc60_perc_2cat gatc7_4 famphase edu_c2cat inc_perc_2cat2mi if nonmiss==1, mi 
sum year if nonmiss==1

*FIGURE 1: Proportion of Couples Undoing Gender in Their Paid and Unpaid Work Arrangements by Year
bysort year: egen my_work42_8h_2cat 		=	mean(work42_8h_2cat) 		if  nonmiss==1
bysort year: egen my_hwcc60_perc_2cat		=	mean(hwcc60_perc_2cat)		if  nonmiss==1
replace my_work42_8h_2cat = my_work42_8h_2cat*100
replace my_hwcc60_perc_2cat = my_hwcc60_perc_2cat*100

twoway connected my_work42_8h_2cat my_hwcc60_perc_2cat year if  nonmiss==1, /// 
	sort msymbol(s o) mcolor(black black)  /// 
	lpattern(solid shortdash) lcolor(black black) /// 
	ylabel(0(10)100, labsize(medium) angle(0)) ///  
	xlabel(2002(1)2011 2014 2017 2020, labsize(medium) angle(90) nogrid) xtitle("") ///
	legend(cols(1) size(medium) label(1 "Undoing gender in paid work")  label(2 "Undoing gender in unpaid work")) ///
	saving("${mygraphs}/figure1", replace)
*Style finilised using Stata graph editor
		
		
*FIGURE 2: Proportion of Couples According to Their Joint Gender Ideology by Year
tab gatc7_4, gen(gatc7_4_)
bysort year: egen my_gatc7_41	=	mean(gatc7_4_1) 	if  nonmiss==1
bysort year: egen my_gatc7_42	=	mean(gatc7_4_2) 	if  nonmiss==1
bysort year: egen my_gatc7_43	=	mean(gatc7_4_3) 	if  nonmiss==1
bysort year: egen my_gatc7_44	=	mean(gatc7_4_4) 	if  nonmiss==1
replace my_gatc7_41 = my_gatc7_41*100
replace my_gatc7_42 = my_gatc7_42*100
replace my_gatc7_43 = my_gatc7_43*100
replace my_gatc7_44 = my_gatc7_44*100

twoway connected my_gatc7_41 my_gatc7_42 my_gatc7_43 my_gatc7_44 year if  nonmiss==1, ///
	sort msymbol(d t t d) lpattern(solid shortdash solid solid) ///
	ylabel(0(10)100, labsize(medium) angle(0)) ///
	xlabel(2002(1)2011 2014 2017 2020, labsize(medium) angle(90) nogrid) xtitle("") ///
	legend(label(1 "Both weak egalitarian") label(2 "Ambivalent, man strong egal.") label(3 "Ambivalent, woman strong egal.") label(4 "Both strong egalitarian") size(medsmall)) ///
	saving("${mygraphs}/figure2", replace)
*Style finilised using Stata graph editor
	

	
*--------------------------------------------------------------------------------------
**# Multivariate analyses
*--------------------------------------------------------------------------------------

** RQ-1: How are couples' gender ideologies related to their arrangements of paid work (1) and unpaid work (2)?
*Regression for panel data: between + within models

** RQ-2: Is the effect of couple's gender ideology moderated by the family life stage?
*Inclusion of an interaction term

*---------------------------------------------
*Variables used in main models:
*---------------------------------------------

*Dependent variable: Undoing gender in paid work
tab work42_8h_2cat  if nonmiss==1
// This variable is also used as control variable regarding interplay among life domains in models assessing unpaid work

*Dependent variable: Undoing gender in unpaid work
tab hwcc60_perc_2cat if nonmiss==1
// This variable is also used as control variable regarding interplay among life domains in models assessing paid work

*Independant variable: Couple's gender ideology
tab gatc7_4 if nonmiss==1

*Independant variable: Family life stage
tab famphase if nonmiss==1

*Control variable: Interview year
sum wave if nonmiss==1

*Control variable: Couple's educational level
tab edu_c2cat if nonmiss==1

*Control variable: Couple's annual income
tab inc_perc_2cat2mi if nonmiss==1


*---------------------------------------------
*MAIN MODELS: Undoing gender in paid work
*---------------------------------------------

estimates drop _all

*Between model (8h differences)
reg work42_8h_2cat b1.gatc7_4 b3.famphase b0.edu_c2cat b0.inc_perc_2cat2mi b0.hwcc60_perc_2cat wave if  nonmiss==1, cluster(idcouple) base
estimates store PWA_reg_workm

margins i.famphase
marginsplot, title("Paid work", size(medium)) subtitle("Between-couple (model 1)", size(medium)) recastci(rbar) ylabel(0(0.1).8, labsize(medium) format("%3.1f") gmax gmin) ytitle("") xlabel(, labsize(medium) angle(90) nogrid) xtitle("")  saving("${mygraphs}/PWA_reg_famphase", replace) 

margins i.gatc7_4
marginsplot, title ("Paid work", size(medium)) subtitle("Between-couple (model 1)", size(medium)) recastci(rbar) ylabel(.1(0.1).5, labsize(medium) format("%3.1f") gmax gmin) ytitle("") xlabel(, labsize(medium) angle(90) nogrid) xtitle("") saving("${mygraphs}/PWA_reg_workm", replace)

margins i.famphase#i.gatc7_4, at(4.gatc7_4)
marginsplot, title("Paid work", size(medium)) subtitle("Between-couple without interaction (model 1)", size(medium)) ylabel(0(0.1).7, labsize(medium) format("%3.1f") gmax gmin) ytitle("") xlabel(, labsize(medium) angle(90) nogrid) xtitle("") saving("${mygraphs}/PWA_reg_famgat", replace) 


*Within model (8h differences)
xtreg work42_8h_2cat b1.gatc7_4 b3.famphase b0.edu_c2cat b0.inc_perc_2cat2mi b0.hwcc60_perc_2cat wave if  nonmiss==1, fe base
estimates store PWA_xtreg_workm


*Between model with interaction (8h differences)
reg work42_8h_2cat b1.gatc7_4##b3.famphase b0.edu_c2cat b0.inc_perc_2cat2mi b0.hwcc60_perc_2cat wave if  nonmiss==1, cluster(idcouple) base
estimates store PWAi_reg_workm

margins i.famphase#i.gatc7_4, at(4.gatc7_4)
marginsplot, title("Paid work", size(medium)) subtitle("Between-couple with interaction (model 5)", size(medium)) ylabel(0(0.1).7, labsize(medium) format("%3.1f") gmax gmin) ytitle("") xlabel(, labsize(medium) angle(90) nogrid) xtitle("")  saving("${mygraphs}/PWAi_reg_famgat", replace)


*---------------------------------------------
*MAIN MODELS: Undoing gender in unpaid work
*---------------------------------------------

*Between model (45-55%)
reg hwcc60_perc_2cat b1.gatc7_4 b3.famphase b0.edu_c2cat b0.inc_perc_2cat2mi b0.work42_8h_2cat wave if  nonmiss==1, cluster(idcouple) base
estimates store UWA_reg_workm

margins i.famphase
marginsplot, title("Unpaid work", size(medium)) subtitle("Between-couple (model 3)", size(medium)) recastci(rbar) ylabel(0(0.1).4, labsize(medium) format("%3.1f") gmax gmin) ytitle("") xlabel(, labsize(medium) angle(90) nogrid) xtitle("") saving("${mygraphs}/UWA_reg_famphase", replace)

margins i.gatc7_4
marginsplot, title ("Unpaid work", size(medium)) subtitle("Between-couple (model 3)", size(medium)) recastci(rbar) ylabel(.1(0.1).5, labsize(medium) format("%3.1f") gmax gmin) ytitle("") xlabel(, labsize(medium) angle(90) nogrid) xtitle("")  saving("${mygraphs}/UWA_reg_workm", replace)

margins i.famphase#i.gatc7_4, at(4.gatc7_4)
marginsplot, title("Unpaid work", size(medium))  subtitle("Between-couple without interaction (model 3)", size(medium)) ylabel(0(0.1).5, labsize(medium) format("%3.1f") gmax gmin) ytitle("") xlabel(, labsize(medium) angle(90) nogrid) xtitle("")  saving("${mygraphs}/UWA_reg_famgat", replace)


*Within model (45-55%)
xtreg hwcc60_perc_2cat b1.gatc7_4 b3.famphase b0.edu_c2cat b0.inc_perc_2cat2mi b0.work42_8h_2cat wave if  nonmiss==1, fe base
estimates store UWA_xtreg_workm


*Between model with interaction (45-55%)
reg hwcc60_perc_2cat b1.gatc7_4##b3.famphase b0.edu_c2cat b0.inc_perc_2cat2mi b0.work42_8h_2cat wave if  nonmiss==1, cluster(idcouple) base
estimates store UWAi_reg_workm

margins i.famphase#i.gatc7_4, at(4.gatc7_4)
marginsplot, title("Unpaid work", size(medium))  subtitle("Between-couple with interaction (model 6)", size(medium)) ylabel(0(0.1).5, labsize(medium) format("%3.1f") gmax gmin) ytitle("") xlabel(, labsize(medium) angle(90) nogrid) xtitle("") saving("${mygraphs}/UWAi_reg_famgat", replace)



*---------------------------------------------
*Multivariate tables and graphs
*---------------------------------------------

*TABLE 2: Probability of Undoing Gender in Paid and Unpaid Work in Switzerland (Linear Probability Models)
esttab PWA_reg_workm PWA_xtreg_workm UWA_reg_workm UWA_xtreg_workm using "$myanalyses\table2.csv", replace b(%9.3f) varwidth(50) r2 pr2 se(%9.3f) not star(* 0.05 ** 0.01 *** 0.001) label aic bic scalars(ll_0 ll chi2)  title("Couple's paid and unpaid work arrangement") mtitles("Model 1" "Model 2" "Model 3" "Model 4") compress


*TABLE 3: Linear Probability Models Including the Interaction Between Couple's Gender Ideology and Family Life Stage
esttab  PWAi_reg_workm UWAi_reg_workm using "$myanalyses\table3.csv", replace b(%9.3f) varwidth(50) r2 pr2 se(%9.3f) not star(* 0.05 ** 0.01 *** 0.001) label aic bic scalars(ll_0 ll chi2)  title("Couple's paid and unpaid work arrangement") mtitles("Model 5" "Model 6") compress


*FIGURE 3: Predicted Probabilities of Undoing Gender by Family Life Stage, with 95 Percent Confidence Intervals (Truncated y-Axes)
graph combine "${mygraphs}/PWA_reg_famphase.gph" "${mygraphs}/UWA_reg_famphase.gph"
graph save "${mygraphs}/figure3", replace
*Style finilised using Stata graph editor


*FIGURE 4: Predicted Probability of Undoing Gender by Couples' Gender Ideology, with 95 Percent Confidence Intervals (Truncated y-Axes)
graph combine "${mygraphs}/PWA_reg_workm.gph" "${mygraphs}/UWA_reg_workm.gph" 
graph save "${mygraphs}/figure4", replace
*Style finilised using Stata graph editor


*FIGURE 5: Predicted Probability of Undoing Gender by Couples' Gender Ideology and Family Life Stage in Models With and Without Interactions, with 95 Percent Confidence Intervals (Truncated y-Axes)
graph combine "${mygraphs}/PWAi_reg_famgat.gph" "${mygraphs}/UWAi_reg_famgat.gph" "${mygraphs}/PWA_reg_famgat.gph" "${mygraphs}/UWA_reg_famgat.gph"
graph save "${mygraphs}/figure5", replace
*Style finilised using Stata graph editor



*---------------------------------------------
*APPENDIX A1: Number of Observations and Sample Attrition Bias
*---------------------------------------------

*1) Using only first obeservation per couple (only between models tested, as no time variation)
*PWA: Between model
reg work42_8h_2cat b1.gatc7_4 b3.famphase b0.edu_c2cat b0.inc_perc_2cat2mi b0.hwcc60_perc_2cat wave if  nonmiss==1 & first_c==1, base // select only couples' first participation
estimates store A1_PWA_reg_workm

*UWA: Between model
reg hwcc60_perc_2cat b1.gatc7_4 b3.famphase b0.edu_c2cat b0.inc_perc_2cat2mi b0.work42_8h_2cat wave if  nonmiss==1 & first_c==1, base // select only couples' first participation
estimates store A1_UWA_reg_workm


*2) Controlling for the total number of participation in the panel and the SHP sample (only between models tested, as time-costant charactistics)

*Couple's total number of participations in the SHP 
cap drop nans_c2
sort idcouple year
bysort idcouple:  gen nans_c2=_N	
lab var nans_c2 "Number of participations of the couple in the SHP"

*SHP sample 
gen filter=1 		if filter20==1 // SHP1 - 1999
replace filter=2 	if filter20==0 // SHP2 - 2004
replace filter=3 	if filter20==4 // SHP3 - 2103
replace filter=4 	if filter20==8 // SHP4 - 2020
tab filter20 filter

*PWA: Between model
reg work42_8h_2cat b1.gatc7_4 b3.famphase b0.edu_c2cat b0.inc_perc_2cat2mi b0.hwcc60_perc_2cat wave nans_c2 b1.filter  if  nonmiss==1, cluster(idcouple) base
estimates store A1_PWA_reg_workm2

*UWA: Between model
reg hwcc60_perc_2cat b1.gatc7_4 b3.famphase b0.edu_c2cat b0.inc_perc_2cat2mi b0.work42_8h_2cat wave nans_c2 b1.filter  if  nonmiss==1, cluster(idcouple) base
estimates store A1_UWA_reg_workm2


esttab PWA_reg_workm A1_PWA_reg_workm A1_PWA_reg_workm2 UWA_reg_workm A1_UWA_reg_workm A1_UWA_reg_workm2 using "$myanalyses\results_A1.csv", replace b(%9.3f) varwidth(50) r2 pr2 se(%9.3f) not star(* 0.05 ** 0.01 *** 0.001) label aic bic scalars(ll_0 ll chi2)  title("Couple's paid and unpaid work arrangement") compress



*---------------------------------------------
*APPENDIX A2: Continuous dependant variables
*---------------------------------------------

*Dependent variable: Undoing gender in paid work
sum work42_c  if nonmiss==1

*Dependent variable: Undoing gender in unpaid work
sum hwcc60_perc_rev if nonmiss==1


*PWA: Between model
reg work42_c b1.gatc7_4 b3.famphase b0.edu_c2cat b0.inc_perc_2cat2mi b0.hwcc60_perc_2cat wave if  nonmiss==1, cluster(idcouple) base
estimates store A2_PWA_reg_workm


*PWA: Within model
xtreg work42_c b1.gatc7_4 b3.famphase b0.edu_c2cat b0.inc_perc_2cat2mi b0.hwcc60_perc_2cat wave if  nonmiss==1, fe base
estimates store A2_PWA_xtreg_workm


*UWA: Between models
reg hwcc60_perc_rev b1.gatc7_4 b3.famphase b0.edu_c2cat b0.inc_perc_2cat2mi b0.work42_8h_2cat wave if  nonmiss==1, cluster(idcouple) base
estimates store A2_UWA_reg_workm


*UWA: Within models
xtreg hwcc60_perc_rev b1.gatc7_4 b3.famphase b0.edu_c2cat b0.inc_perc_2cat2mi b0.work42_8h_2cat wave if  nonmiss==1, fe base
estimates store A2_UWA_xtreg_workm


esttab PWA_reg_workm A2_PWA_reg_workm PWA_xtreg_workm A2_PWA_xtreg_workm UWA_reg_workm A2_UWA_reg_workm UWA_xtreg_workm A2_UWA_xtreg_workm using "$myanalyses\results_A2.csv", replace b(%9.3f) varwidth(50) r2 pr2 se(%9.3f) not star(* 0.05 ** 0.01 *** 0.001) label aic bic scalars(ll_0 ll chi2)  title("Couple's paid and unpaid work arrangement") compress



*---------------------------------------------
*APPENDIX A3: Alternative dependent variables: Paid work, housework and childcare
*---------------------------------------------

*Dependent variable: Undoing gender in paid work (45-55%)
tab work42_2cat  if nonmiss==1

*Dependent variable: Undoing gender in housework work (45-55%)
tab hw60_perc_2cat if nonmiss==1

*Dependent variable: Undoing gender in childcare work (45-55%)
tab cct_perc_2cat if nonmiss==1


*PWA: Between model (45-55%)
reg work42_2cat b1.gatc7_4 b3.famphase b0.edu_c2cat b0.inc_perc_2cat2mi b0.hwcc60_perc_2cat wave if  nonmiss==1, cluster(idcouple) base
estimates store A3_PWA_reg_workm

*PWA: Within model (45-55%)
xtreg work42_2cat b1.gatc7_4 b3.famphase b0.edu_c2cat b0.inc_perc_2cat2mi b0.hwcc60_perc_2cat wave if  nonmiss==1, fe base
estimates store A3_PWA_xtreg_workm


*HWA: Between model
reg hw60_perc_2cat b1.gatc7_4 b3.famphase b0.edu_c2cat b0.inc_perc_2cat2mi b0.work42_8h_2cat wave if  nonmiss==1, cluster(idcouple) base
estimates store A3_HWA_reg_workm

*HWA: Within model
xtreg hw60_perc_2cat b1.gatc7_4 b3.famphase b0.edu_c2cat b0.inc_perc_2cat2mi b0.work42_8h_2cat wave if  nonmiss==1, fe base
estimates store A3_HWA_xtreg_workm


*CWA: Between model
reg cct_perc_2cat b1.gatc7_4 b3.famphase b0.edu_c2cat b0.inc_perc_2cat2mi b0.work42_8h_2cat wave if  nonmiss==1, cluster(idcouple) base
estimates store A3_CWA_reg_workm

*CWA: Within model
xtreg cct_perc_2cat b1.gatc7_4 b3.famphase b0.edu_c2cat b0.inc_perc_2cat2mi b0.work42_8h_2cat wave if  nonmiss==1, fe base
estimates store A3_CWA_xtreg_workm


esttab PWA_reg_workm A3_PWA_reg_workm PWA_xtreg_workm A3_PWA_xtreg_workm UWA_reg_workm A3_HWA_reg_workm A3_CWA_reg_workm UWA_xtreg_workm A3_HWA_xtreg_workm  A3_CWA_xtreg_workm using "$myanalyses\results_A3.csv", replace b(%9.3f) varwidth(50) r2 pr2 se(%9.3f) not star(* 0.05 ** 0.01 *** 0.001) label aic bic scalars(ll_0 ll chi2)  title("Couple's paid and unpaid work arrangement") compress



*---------------------------------------------------------------
*APPENDIX A4: Alternative variables for couple's gender ideology
*---------------------------------------------------------------

*Independant variable: Couple's gender ideology based on attitudes toward maternal employment, threshold at 8
tab gatc8_4 if nonmiss==1

*Independant variable: Couple's gender ideology based on attitudes toward women's employment, threshold at 10
tab gatc_ind_4 if nonmiss==1


*PWA: Between model
reg work42_8h_2cat b1.gatc8_4 b3.famphase b0.edu_c2cat b0.inc_perc_2cat2mi b0.hwcc60_perc_2cat wave if  nonmiss==1, cluster(idcouple) base
estimates store A4_PWA_reg_workm8

reg work42_8h_2cat b1.gatc_ind_4 b3.famphase b0.edu_c2cat b0.inc_perc_2cat2mi b0.hwcc60_perc_2cat wave, cluster(idcouple) base
estimates store A4_PWA_reg_workw


*PWA: Within model
xtreg work42_8h_2cat b1.gatc8_4 b3.famphase b0.edu_c2cat b0.inc_perc_2cat2mi b0.hwcc60_perc_2cat wave if  nonmiss==1, fe base
estimates store A4_PWA_xtreg_workm8

xtreg work42_8h_2cat b1.gatc_ind_4 b3.famphase b0.edu_c2cat b0.inc_perc_2cat2mi b0.hwcc60_perc_2cat wave, fe base
estimates store A4_PWA_xtreg_workw


*UWA: Between model
reg hwcc60_perc_2cat b1.gatc8_4 b3.famphase b0.edu_c2cat b0.inc_perc_2cat2mi b0.work42_8h_2cat wave if  nonmiss==1, cluster(idcouple) base
estimates store A4_UWA_reg_workm8

reg hwcc60_perc_2cat b1.gatc_ind_4 b3.famphase b0.edu_c2cat b0.inc_perc_2cat2mi b0.work42_8h_2cat wave, cluster(idcouple) base
estimates store A4_UWA_reg_workw


*UWA: Within model
xtreg hwcc60_perc_2cat b1.gatc8_4 b3.famphase b0.edu_c2cat b0.inc_perc_2cat2mi b0.work42_8h_2cat wave if  nonmiss==1, fe base
estimates store A4_UWA_xtreg_workm8

xtreg hwcc60_perc_2cat b1.gatc_ind_4 b3.famphase b0.edu_c2cat b0.inc_perc_2cat2mi b0.work42_8h_2cat wave, fe base
estimates store A4_UWA_xtreg_workw


esttab PWA_reg_workm A4_PWA_reg_workm8 A4_PWA_reg_workw PWA_xtreg_workm A4_PWA_xtreg_workm8  A4_PWA_xtreg_workw UWA_reg_workm A4_UWA_reg_workm8 A4_UWA_reg_workw UWA_xtreg_workm A4_UWA_xtreg_workm8 A4_UWA_xtreg_workw using "$myanalyses\results_A4.csv", replace b(%9.3f) varwidth(50) r2 pr2 se(%9.3f) not star(* 0.05 ** 0.01 *** 0.001) label aic bic scalars(ll_0 ll chi2)  title("Couple's paid and unpaid work arrangement") compress


*---------------------------------------------------------------
*APPENDIX A5: Alternative control variables 
*---------------------------------------------------------------

*Control variable: Each partner's educational level
tab1 edu2 edu2_p if nonmiss==1

*Control variable: Male partner's annual income
//Creation of a variable based on percentiles to address the  skewed distribution of income.
cap drop incomei_p5cat
xtile incomei_p5cat = incomei_p if nonmiss==1, nq(5)
replace  incomei_p5cat = 6 if incomei_p5cat==. // for missing values
tab incomei_p5cat if nonmiss==1

*Control variable: External support received in unpaid work
tab hf03 // external support for housework tasks
clonevar hw_extern=hf03
replace hw_extern=2 if hw_extern==.
label define externhelp 1"yes" 2"no or missing"
label values hw_extern externhelp
label var hw_extern "External help in housework"

tab hf36 // external support for childcare
clonevar cc_extern=hf36
replace cc_extern=2 if cc_extern==. 
label values cc_extern externhelp
label var cc_extern "External help in childcare"

clonevar hwcc_extern=hw_extern // any external support for unpaid work
replace hwcc_extern=1 if cc_extern==1 & inlist(hwcc_extern,2)
replace hwcc_extern=2 if hwcc_extern==.
label values hwcc_extern externhelp
label var hwcc_extern "External help in unpaid work"

tab1 hwcc_extern if nonmiss==1, mi


*PWA: Between model
reg work42_8h_2cat b1.gatc7_4 b3.famphase b0.edu2 b0.edu2_p b0.inc_perc_2cat2mi b0.hwcc60_perc_2cat wave if  nonmiss==1, cluster(idcouple) base
estimates store A5_PWA_reg_workm1

reg work42_8h_2cat b1.gatc7_4 b3.famphase b0.edu_c2cat b3.incomei_p5cat b0.hwcc60_perc_2cat wave if  nonmiss==1, cluster(idcouple) base
estimates store A5_PWA_reg_workm2


*PWA: Within model
xtreg work42_8h_2cat b1.gatc7_4 b3.famphase b0.edu2 b0.edu2_p b0.inc_perc_2cat2mi b0.hwcc60_perc_2cat wave  if  nonmiss==1, fe base
estimates store A5_PWA_xtreg_workm1

xtreg work42_8h_2cat b1.gatc7_4 b3.famphase b0.edu_c2cat b3.incomei_p5cat b0.hwcc60_perc_2cat wave, fe base
estimates store A5_PWA_xtreg_workm2


*UWA: Between model
reg hwcc60_perc_2cat b1.gatc7_4 b3.famphase b0.edu_c2cat b0.inc_perc_2cat2mi b2.hwcc_extern b0.work42_8h_2cat wave, cluster(idcouple) base
estimates store A5_UWA_reg_workm


*UWA: Within model
xtreg hwcc60_perc_2cat b1.gatc7_4 b3.famphase b0.edu_c2cat b0.inc_perc_2cat2mi b2.hwcc_extern b0.work42_8h_2cat wave, fe base
estimates store A5_UWA_xtreg_workm


esttab PWA_reg_workm A5_PWA_reg_workm1 A5_PWA_reg_workm2 PWA_xtreg_workm A5_PWA_xtreg_workm1 A5_PWA_xtreg_workm2 UWA_reg_workm A5_UWA_reg_workm UWA_xtreg_workm A5_UWA_xtreg_workm using "$myanalyses\results_A5.csv", replace b(%9.3f) varwidth(50) r2 pr2 se(%9.3f) not star(* 0.05 ** 0.01 *** 0.001) label aic bic scalars(ll_0 ll chi2)  title("Couple's paid and unpaid work arrangement") compress



*---------------------------------------------------------------
*APPENDIX A6: Alternative analyses using logistic regression models 
*---------------------------------------------------------------

*PWA: Between model
logit work42_8h_2cat b1.gatc7_4 b3.famphase b0.edu_c2cat b0.inc_perc_2cat2mi b0.hwcc60_perc_2cat wave if  nonmiss==1, cluster(idcouple) base
estimates store A6_PWA_logit_workm

*PWA: Within model 
xtlogit work42_8h_2cat b1.gatc7_4 b3.famphase b0.edu_c2cat b0.inc_perc_2cat2mi b0.hwcc60_perc_2cat wave if  nonmiss==1, fe base
estimates store A6_PWA_xtlogit_workm

*UWA: Between model
logit hwcc60_perc_2cat b1.gatc7_4 b3.famphase b0.edu_c2cat b0.inc_perc_2cat2mi b0.work42_8h_2cat wave if  nonmiss==1, cluster(idcouple) base
estimates store A6_UWA_logit_workm

*UWA: Within model
xtlogit hwcc60_perc_2cat b1.gatc7_4 b3.famphase b0.edu_c2cat b0.inc_perc_2cat2mi b0.work42_8h_2cat wave if  nonmiss==1, fe base
estimates store A6_UWA_xtlogit_workm

esttab PWA_reg_workm  A6_PWA_logit_workm PWA_xtreg_workm A6_PWA_xtlogit_workm  UWA_reg_workm  A6_UWA_logit_workm UWA_xtreg_workm  A6_UWA_xtlogit_workm using "$myanalyses\results_A6.csv", replace b(%9.3f) varwidth(50) r2 pr2 se(%9.3f) not star(* 0.05 ** 0.01 *** 0.001) label aic bic scalars(ll_0 ll chi2)  title("Couple's paid and unpaid work arrangement") compress

compress

log close

