*****************************************************************************************************
* Beyond tradition? How gender ideology impacts employment and family arrangements in Swiss couples
* Data Management 1 - Creation of the individual long file
*****************************************************************************************************

/* 
Preliminary information:

This stata syntax allows to reproduce the analyses included in the following article (and related online appendix):
Bornatici, C., & Zinn, I. (2025). Beyond tradition? How gender ideology impacts employment and family arrangements in Swiss couples. Gender & Society.

The data and documentation files are available from the platform SWISSUbase:
Swiss Household Panel (2022). Living in Switzerland waves 1-22 (V5.1.0) [Dataset]. FORS – Swiss Centre of Expertise in the Social Sciences. http://doi.org/10.48573/1nav-wy98.

Code author: Christina Bornatici, FORS – Swiss Centre of Expertise in the Social Sciences, University of Lausanne, Switzerland; on the basis of Ursina Kuhn's syntax to merge SHP data files

After downloading the data, adapt the paths (below, and in each syntax) and run the syntaxes one after the other (i.e., Data_management_1 Data_management_2 Data_management_3 Data_management_4 Data_analysis_1) to replicate the results.
*/

// Set paths (to adapt)
global shpdata    	C:\Users\Data_original_file
global mydata 		C:\Users\Data_worked_file
global mylogfiles	C:\Users\Log files
global myanalyses	C:\Users\Data_analysis
global mygraphs		C:\Users\Graphs

version 17 // set a version as commands may vary between versions
set more off  // tells Stata not to pause after each page

capture log close // closes log file if any is open
log using "$mylogfiles\Creation_Individual_File.smcl", replace

use "$shpdata\shp20_p_user.dta", clear


*----------------------------------------------------------------------
* Merging and appending data from the original SHP files 
*----------------------------------------------------------------------

*---------Step 1: Macros for variables

// all variables we want in the file
local varstokeep ///
	idhous`y' idpers  idspou`y' status`y' refper relarp`y' /// IDs
	nbadul`y' nbpers`y' aoldki`y' ayouki`y' nbkid`y' aduk1_`y' aduk2_`y' /// household characteristics and children
	sex`y' age`y' birthy  /// personal charactistics
	educat`y' /// education
	wstat`y' occupa`y' p`y'w74 p`y'w77 p`y'w108 p`y'w610 /// paid work
	i`y'ptotg /// income 
	p`y'd91 p`y'd92 /// gender ideology
	p`y'f08 /// household work weekly hours
	h`y'f57 h`y'f58 h`y'f59 h`y'f60 /// household work tasks
	p`y'f63 /// childcare work weekly hours, only asked since 2019
	h`y'f54 h`y'f55 h`y'f56 /// childcare tasks
	h`y'f03 h`y'f36 // external support for unpaid work

// constructed variables (year identifier at the end)
local construct ///	
		idhous`y' idpers idspou`y' status`y' refper relarp`y' /// IDs
		nbadul`y' nbpers`y' aoldki`y' ayouki`y' nbkid`y' aduk1_`y' aduk2_`y' /// household characteristics and children
		sex`y' age`y' birthy /// personal charactistics
		educat`y' /// education
		wstat`y' occupa`y' // paid work

		
*---------Step 2: Temporary files from SHP
// this part has to be run together with part 1.1 above in Stata

local wave=1 // macro which adds 1 for each year
foreach y in 99 00 01 02 03 04 05 06 07 08 09 10 11 12 13 14 15 16 17 18 19 20 { 
disp `y'
use "$shpdata\shp`y'_p_user", clear

merge m:1 idhous`y' using "$shpdata\shp`y'_h_user",  nogen
 
renpfix p`y' p
renpfix i`y' i
renpfix h`y' h

	// rename constructud variables
	    local torename 
		foreach var of local construct {
			capture confirm variable `var'             
			if (!_rc) local torename `torename' `var'  
			} 
		renvars `torename', postsub(`y')	
	
	// create wave indicator (1, 2, ...)
 	gen wave = `wave'   
    
 	// select variables needed
	if ("`varstokeep'"!="") {
		local tokeep                                 // empty to keep list
		foreach var of local varstokeep {            // loop over all selected variables
			capture confirm variable `var'           // check whether variable exists in current wave
			if (!_rc) local tokeep `tokeep' `var'    // mark for inclusion if variable exists
			}
		keep idpers wave `tokeep' 	 // keep selected variables
        }
	
local wave = `wave'+1  // Increase (wave) counter by 1

		
	// Save temporary data file
	save "$mydata\temp`y'", replace
 }


*---------Step 3: Merge and append files

// temporary files from personal and houehold file
use "$mydata\temp20", clear 
foreach y in 99 00 01 02 03 04 05 06 07 08 09 10 11 12 13 14 15 16 17 18 19 { 
append using "$mydata\temp`y'"
}

// master file 
merge m:1 idpers using "$shpdata\shp_mp", keepusing (sex birthy filter20) /// 
 keep (1 3) nogen


 
*----------------------------------------------------------------------
* Organisation of variables and cleaning of missing values
*----------------------------------------------------------------------

*Wave and year variables
gen year=wave+1998

label def wave 1 "1999" 2 "2000" 3 "2001" 4 "2002" 5 "2003" 6 "2004" 7 "2005" 8 "2006" 9 "2007" 10 "2008" 11 "2009" 12 "2010" 13 "2011" 14 "2012" 15 "2013" 16 "2014" 17 "2015" 18 "2016" 19 "2017" 20 "2018" 21 "2019" 22"2020" 
label val wave wave
tab wave, miss


*Ordering of variables in the file
order ///
	idhous idpers status year wave filter20 idspou refper relarp sex age birthy  /// IDs and personal charactistics
	nbpers nbadul nbkid ayouki aoldki aduk2_ aduk1_ /// household characteristics and children
	pd91 pd92 /// gender ideology
	educat /// educational level
	wstat occupa pw74 pw77 pw108 pw610  /// paid work 
	iptotg /// income
	pf08 /// household work weekly hours
	hf57 hf58 hf59 hf60 /// household work tasks
	pf63 /// childcare work weekly hours, only asked since 2019
	hf54 hf55 hf56 /// childcare tasks
	hf03 hf36, first // external support for unpaid work


*Correction of spoten mistakes
replace ayouki=1 if idpers==1706102 & year==2003
replace ayouki=1 if idpers==1706101 & year==2003
replace nbadul=2 if idhous==102371 & year==1999 


*Get rid of all the missings
recode _all (min/-1=.)



*----------------------------------------------------------------------
* Keeping only respondents answering individual questionnaire
*----------------------------------------------------------------------

drop if status!=0 		// drop if respondent did not answer to the individual questionnaire (needed for attitudinal variables)  
  

compress

save "${mydata}\shp_individual", replace

log close
