*****************************************************************************************************
* Beyond tradition? How gender ideology impacts employment and family arrangements in Swiss couples
* Data Management 2 - Individual variables
*****************************************************************************************************

/* 
Preliminary information:

This stata syntax allows to reproduce the analyses included in the following article (and related online appendix):
Bornatici, C., & Zinn, I. (2025). Beyond tradition? How gender ideology impacts employment and family arrangements in Swiss couples. Gender & Society.

The data and documentation files are available from the platform SWISSUbase:
Swiss Household Panel (2022). Living in Switzerland waves 1-22 (V5.1.0) [Dataset]. FORS – Swiss Centre of Expertise in the Social Sciences. http://doi.org/10.48573/1nav-wy98.

Code author: Christina Bornatici, FORS – Swiss Centre of Expertise in the Social Sciences, University of Lausanne, Switzerland

After downloading the data, adapt the paths (below, and in each syntax) and run the syntaxes one after the other (i.e., Data_management_1 Data_management_2 Data_management_3 Data_management_4 Data_analysis_1) to replicate the results.
*/

// Set paths (to adapt)
global shpdata    	C:\Users\Data_original_file
global mydata 		C:\Users\Data_worked_file
global mylogfiles	C:\Users\Log files
global myanalyses	C:\Users\Data_analysis
global mygraphs		C:\Users\Graphs

version 17 // set a version as commands may vary between versions
set more off  // tells Stata not to pause after each page

capture log close // closes log file if any is open
log using "$mylogfiles\IndividualOtherVariables.smcl", replace

use "${mydata}\shp_individual", clear
sort idpers year
xtset idpers year // declare data as panel


*--------------------------------------------------------------------------------------
* Gender ideology
*--------------------------------------------------------------------------------------

**Attitudes toward maternal employment
*A pre-school child suffers, if his or her mother works for pay.
	// 2002-2011, 2014, 2017, 2020
	// 0 means "I completely disagree" and 10 "I completely agree"
gen gat_workm	=	pd92
	label variable gat_workm "Child suffers with working mother"
	recode gat_workm	(0=10 "Disagree - Child does not suffer") (1=9) (2=8) (3=7) (4=6) (5=5) (6=4) (7=3) (8=2) (9=1) (10=0 "Agree - Child suffers"), gen(gat_workm_rev)
	label variable gat_workm_rev "Child suffers with working mother(reverse)"	
	
tab gat_workm	gat_workm_rev, mi

drop gat_workm

label define att_str3_lbl 1 "Strong traditional attitudes" 2 "Middle attitudes" 3 "Strong egalitarian attitudes"
label define att_str_lbl 0 "Less egalitarian" 1 "Strong egalitarian"

*Threshold at 7, 3cat
foreach attitude of varlist gat_workm_rev  {    
gen `attitude'_str7=3 		if inlist(`attitude',7,8,9,10)
replace `attitude'_str7=2 	if inlist(`attitude',4,5,6)
replace `attitude'_str7=1 	if inlist(`attitude',0,1,2,3)
label values `attitude'_str7 att_str3_lbl
label variable `attitude'_str7 "`attitude': strength (7,8,9,10)"
}

*Threshold at 8, 3cat
foreach attitude of varlist gat_workm_rev  {    
gen `attitude'_str8=3 		if inlist(`attitude',8,9,10)
replace `attitude'_str8=2 	if inlist(`attitude',3,4,5,6,7)
replace `attitude'_str8=1 	if inlist(`attitude',0,1,2)
label values `attitude'_str8 att_str3_lbl
label variable `attitude'_str8 "`attitude': strength"
}

label variable gat_workm_rev_str7 "Child suffers with working mother(reverse)"	
label variable gat_workm_rev_str8 "Child suffers with working mother(reverse)"	


**Attitudes toward women's employment
*To have a job is the best guarantee for a woman as for a man to be independent
	// 2002-2011, 2014, 2017, 2020
	// 0 means "I completely disagree" and 10 "I completely agree"
gen gat_ind	= pd91
	label variable gat_ind "Job preserves independance"
	label define gat_ind 0 "Disagree - Job does not preserve independance" 10 "Agree - Job preserves independence"
	label values gat_ind gat_ind
	
*Threshold at 10, 3cat
gen gat_ind_str10=3 if gat_ind==10
replace gat_ind_str10=2 if inlist(gat_ind,9,8,7)
replace gat_ind_str10=1 if inlist(gat_ind,0,1,2,3,4,5,6)
label variable gat_ind_str10 "Job preserves independance"


**Attitudes toward maternal employment and Attitudes toward women's employment
*2cat
foreach str_attitude of varlist gat_workm_rev_str7 gat_workm_rev_str8 gat_ind_str10  { 
gen `str_attitude'_01=1 		if inlist(`str_attitude',3)
replace `str_attitude'_01=0 	if inlist(`str_attitude',1,2)
label values `str_attitude'_01 att_str_lbl
label variable `str_attitude'_01 "Strong egalitarian"
}

label variable gat_workm_rev_str7_01 "Child suffers with working mother(reverse)"	
label variable gat_workm_rev_str8_01 "Child suffers with working mother(reverse)"
label variable gat_ind_str10_01 "Job preserves independance"


*--------------------------------------------------------------------
*  Paid work
*--------------------------------------------------------------------
/*
//weekly hours
	tab pw74	// CMJ-Contractual hours per week (2000-all)
	tab pw77 	// CMJ - Hours done per week (all waves)
	tab pw108 	// CSJ: Work: Hours per week (1999-2003)
	tab pw610	// Total hours per week, all jobs (2004-all)
	
//part-time/full-time
		// The categories are generated based on OFS/BFS information (OFS_1991-2015_part-full time.xls + http://www.bfs.admin.ch/bfs/portal/en/index/themen/03/02/blank/key/arbeitszeit0/normale_arbeitszeit.html)
		// 100%=42h --> 1)calculation: 90/37.8 80/33.6 75/31.5 60/25.2 50/21 40/16.8 25/10.5 20/8.4 --> 2)rund up/down to get whole numbers(CB)

100	42,0 > 42
90	37,8 > 38
80	33,6 > 34
70	29,4 > 29
60	25,2 > 25
50	21,0 > 21
40	16,8 > 17
30	12,6 > 13
20	8,4  > 8
10	4,2  > 4
0	0,0  > 0
*/	

cap drop workhours
clonevar workhours=pw610
replace workhours=pw77+pw108 if workhours==.
replace workhours=pw77 if workhours==.
replace workhours=pw108 if workhours==.
replace workhours=pw74 if workhours==.
	replace workhours=0 if inlist(wstat, 2,3) & workhours==.
	replace workhours=0 if inlist(occupa, 4,5,6,7,8,9,10,11) & workhours==.
	label variable workhours "Hours done per week in paid work"

	
	
*--------------------------------------------------------------------
*  Household work
*--------------------------------------------------------------------

clonevar hwhours=pf08 //Individual weekly hours



*--------------------------------------------------------------------
*  Childcare work
*--------------------------------------------------------------------
//For tasks, only asked if children less than 15 years old
//For weekly hours, only available since 2019 pf63
clonevar cchours=pf63



*--------------------------------------------------------------------
* Educational level
*--------------------------------------------------------------------	
 	
recode educat 0/3=1 4/6=2 7/10=3, gen (edu3)
	label def edu3 1 "Low education" 2 "Intermediate education" 3 "High education"
	label val edu3 edu3
	label var edu3 "Education level"

recode edu3 (1=0 "Secondary and below") (2=0) (3=1 "Tertiary"), gen(edu2)
	label var edu2 "Education level"



*--------------------------------------------------------------------
* Income
*--------------------------------------------------------------------	

gen incomei=iptotg 
replace incomei=0 if workhours==0 & incomei==.
replace incomei=incomei/1000



compress // stores variables as efficient as possible

save "${mydata}\shp_individual_variables", replace

log close
