*****************************************************************************************************
* Beyond tradition? How gender ideology impacts employment and family arrangements in Swiss couples
* Data Management 3 - Creation of the couple file
*****************************************************************************************************

/* 
Preliminary information:

This stata syntax allows to reproduce the analyses included in the following article (and related online appendix):
Bornatici, C., & Zinn, I. (2025). Beyond tradition? How gender ideology impacts employment and family arrangements in Swiss couples. Gender & Society.

The data and documentation files are available from the platform SWISSUbase:
Swiss Household Panel (2022). Living in Switzerland waves 1-22 (V5.1.0) [Dataset]. FORS – Swiss Centre of Expertise in the Social Sciences. http://doi.org/10.48573/1nav-wy98.

Code author: Christina Bornatici, FORS – Swiss Centre of Expertise in the Social Sciences, University of Lausanne, Switzerland

After downloading the data, adapt the paths (below, and in each syntax) and run the syntaxes one after the other (i.e., Data_management_1 Data_management_2 Data_management_3 Data_management_4 Data_analysis_1) to replicate the results.
*/

// Set paths (to adapt)
global shpdata    	C:\Users\Data_original_file
global mydata 		C:\Users\Data_worked_file
global mylogfiles	C:\Users\Log files
global myanalyses	C:\Users\Data_analysis
global mygraphs		C:\Users\Graphs

version 17 // set a version as commands may vary between versions
set more off  // tells Stata not to pause after each page

capture log close // closes log file if any is open
log using "$mylogfiles\Creation_Couple_File.smcl", replace


*------------------------------------------------------------------
* Step 1: Creation of the partner file
*------------------------------------------------------------------
use "${mydata}\shp_individual_variables.dta", clear

renvars _all, postfix(_p)

tab sex_p, mi

drop idspou_p

rename idpers_p idspou
label var idspou "Identification number of partner or spouse (hetero or homosexual)"
rename idhous_p idhous
rename year_p year

save "${mydata}\shp_partner.dta", replace


*------------------------------------------------------------------
* Step 2: Merging individual long file and partner file
*------------------------------------------------------------------

* 1. sort both files: 
sort idhous idspou year
save "$mydata\shp_partner.dta", replace

clear
use "${mydata}\shp_individual_variables.dta", clear
sort idhous idspou year

* 2. merge: 
cap drop _merge _merge_p
merge m:1 idhous idspou year using "$mydata\shp_partner.dta"


*------------------------------------------------------------------
* Step 3: Keeping only heterosexual couples ...
*------------------------------------------------------------------

keep if _merge==3
tab _merge

tab1 relarp relarp_p, mi
keep if inlist(relarp,1,2,3)
keep if inlist(relarp_p,1,2,3)

gen same_sex_couple=0 
	replace same_sex_couple=1 if sex==1 & sex_p==1
	replace same_sex_couple=1 if sex==2 & sex_p==2
	label def dummy 0"No" 1"Yes" 					
	label value same_sex_couple dummy
	label var same_sex_couple "Homosexual couple"
tab same_sex_couple, mi

drop if same_sex_couple==1		// keep only hetero couples					
drop if sex==1 					// keep women as 1st person in hetero couples


*----------------------------------------------------------------------
* Step 4: ... of working age
*----------------------------------------------------------------------

gen adukid=aduk1_+aduk2_
lab var adukid "Number of adult children living in the household"
	
gen totkid=adukid+nbkid
lab var totkid "Number of children (adult or not) living in the household"
	
gen tt=nbpers-totkid

gen hetero_1864=1 if age>17 & age<65 & age_p>17 & age_p<65 & tt==2
	replace hetero_1864=. if aduk2_>0
	label var hetero_1864 "Individual 18-64 in hetero couple (no other adults) and children below 30"
		
keep if hetero_1864==1

capture drop first_c_new
sort idpers idspou year
bysort idpers idspou: gen first_c_new=_n==1

capt drop idcouple
sort idpers year
bysort first_c_new:  gen idcouple=_n if first_c_new==1
sort idpers year 
foreach i of numlist 1/22 {    
bysort idpers: replace idcouple=l`i'.idcouple if idcouple==.
}
lab var idcouple "Couple identification number"
	
save "${mydata}\shp_couple_hetero_1864", replace
*CURRENT SAMPLING
*only individuals who answered the questionnaire (status==0), needed for attitudinal variables
*only individuals in couples (with an IDSPOU)
*only heterosexual couples
*only respondents who are reference person or spouse/cohabitant of reference person
*only partners in working age
*only couples leaving without other adults or children older than 30


log close