*****************************************************************************************************
* Beyond tradition? How gender ideology impacts employment and family arrangements in Swiss couples
* Data Management 4 - Couple variables
*****************************************************************************************************

/* 
Preliminary information:

This stata syntax allows to reproduce the analyses included in the following article (and related online appendix):
Bornatici, C., & Zinn, I. (2025). Beyond tradition? How gender ideology impacts employment and family arrangements in Swiss couples. Gender & Society.

The data and documentation files are available from the platform SWISSUbase:
Swiss Household Panel (2022). Living in Switzerland waves 1-22 (V5.1.0) [Dataset]. FORS – Swiss Centre of Expertise in the Social Sciences. http://doi.org/10.48573/1nav-wy98.

Code author: Christina Bornatici, FORS – Swiss Centre of Expertise in the Social Sciences, University of Lausanne, Switzerland

After downloading the data, adapt the paths (below, and in each syntax) and run the syntaxes one after the other (i.e., Data_management_1 Data_management_2 Data_management_3 Data_management_4 Data_analysis_1) to replicate the results.
*/

// Set paths (to adapt)
global shpdata    	C:\Users\Data_original_file
global mydata 		C:\Users\Data_worked_file
global mylogfiles	C:\Users\Log files
global myanalyses	C:\Users\Data_analysis
global mygraphs		C:\Users\Graphs

version 17 // set a version as commands may vary between versions
set more off  // tells Stata not to pause after each page

capture log close // closes log file if any is open
log using "$mylogfiles\Couple_Variables.smcl", replace

use "${mydata}\shp_couple_hetero_1864", clear

order idpers year
xtset, clear
xtset idcouple year
xtdes

**# Bookmark #1
*--------------------------------------------------------------------
* Couple's gender ideology
*--------------------------------------------------------------------
label define gat_c_lbl 	1 "Both weak egalitarian" 2"Ambivalent, man str. egal." 3"Ambivalent, woman str. egal." 4 "Both strong egalitarian"

foreach attitude of varlist gat_workm_rev_str7_01 gat_workm_rev_str8_01 gat_ind_str10_01 { 
gen `attitude'_c=.
replace `attitude'_c=1 if `attitude'==0 & `attitude'_p==0
replace `attitude'_c=2 if `attitude'==0 & `attitude'_p==1
replace `attitude'_c=3 if `attitude'==1 & `attitude'_p==0
replace `attitude'_c=4 if `attitude'==1 & `attitude'_p==1
label values `attitude'_c gat_c_lbl
label variable `attitude'_c "`attitude'_c: strong egalitarian"
}

gen gatc7_4=gat_workm_rev_str7_01_c 
gen gatc8_4=gat_workm_rev_str8_01_c 
gen gatc_ind_4=gat_ind_str10_01_c

foreach var of varlist gatc7_4 gatc8_4  gatc_ind_4 {
label values `var' gat_c_lbl
}

label variable gatc7_4 "Couple's gender ideology (maternal employment)"	
label variable gatc8_4 "Couple's gender ideology (maternal employment)"
label variable gatc_ind_4 "Couple's gender ideology (women's employment)"

drop gat_workm_rev_str7_01_c gat_workm_rev_str8_01_c gat_ind_str10_01_c


**# Bookmark #2
*--------------------------------------------------------------------
* Couple's family life stages
*--------------------------------------------------------------------
cap drop adukid
gen adukid=aduk1_+aduk2_
lab var adukid "Number of adult children living in the household"

cap drop totkid	
gen totkid=adukid+nbkid
lab var totkid "Number of children (adult or not) living in the household"
	
recode ayouki (0/4=1) (5/17=2), gen(youngkid)
label def youngkid 1"Youngest child below school age" 2"Youngest child at school"
label val youngkid youngkid
label var youngkid "Youngest child"

cap drop famphase
sort idcouple year
gen famphase=. // according to Levy et al. 1997
replace famphase=2 if totkid>0 & totkid!=. & youngkid==1
replace famphase=3 if totkid>0 & totkid!=. & youngkid==2 & famphase==.
replace famphase=4 if adukid>0 & adukid!=. & famphase==.
foreach i of numlist 1/22 { 
bysort idcouple: replace famphase=5 if l`i'.famphase==4 & totkid==0 & famphase==.
bysort idcouple: replace famphase=5 if l`i'.famphase==3 & totkid==0 & famphase==.
bysort idcouple: replace famphase=5 if l`i'.famphase==2 & totkid==0 & famphase==.
}
replace famphase=1 if totkid==0 & age<45 & famphase==.	
replace famphase=6 if totkid==0 & age>=45 & age!=. & famphase==.	
label def famphase_lbl 1"Pre-child couple" 2"Preschool family" 3"School family" 4"Post-school family" 5"Couple post-children" 6"Childless couple"
label val famphase famphase_lbl
label var famphase "Family life stage" 

	
	
**# Bookmark #3
*--------------------------------------------------------------------
* Couple's paid work arrangement
*--------------------------------------------------------------------

label define m_w_ratio 1 "Man more" 2 "Equal" 3 "Woman more"

gen workhours42=workhours
replace workhours42=42 if workhours>=42 & workhours!=.

gen workhours42_p=workhours_p
replace workhours42_p=42 if workhours_p>=42 & workhours_p!=.

gen work42_c=workhours42-workhours42_p // min = doing gender , max = undoing gender
label variable work42_c "Difference in couple's paid work hours"

gen work42_c1=workhours42_p-workhours42


*8-hour difference
gen work42_8h_3cat=1			if	work42_c1>8
replace work42_8h_3cat=2		if	-8<=work42_c1 & work42_c1<=8
replace work42_8h_3cat=3		if	work42_c1<-8
replace work42_8h_3cat=.		if	workhours42==. | workhours42_p==.
label values work42_8h_3cat m_w_ratio
label var work42_8h_3cat "Couple's paid work arrangement (8h difference, max 42h)"

recode work42_8h_3cat (1=0 "Doing gender, man more") (2/3=1 "Undoing gender, equal or woman more"), gen(work42_8h_2cat)


*45-55% difference
gen work42_cX=(workhours42/(workhours42+workhours42_p))*100 // min = doing gender , max = undoing 
replace work42_cX=50 if workhours42+workhours42_p==0
label variable work42_cX "Woman's share of paid work"

gen work42_3cat=1 		if 	work42_cX<45
replace work42_3cat=2 	if 	work42_cX>=45 & work42_cX<=55
replace work42_3cat=3 	if 	work42_cX>55  & work42_cX!=. 
label variable work42_3cat "Couple's housework arrangement"
label values work42_3cat m_w_ratio

recode work42_3cat (1=0 "Doing gender, man more") (2/3=1 "Undoing gender, equal or woman more"), gen(work42_2cat)



**# Bookmark #4
*--------------------------------------------------------------------
* Couple's housework arrangement
*--------------------------------------------------------------------
*Step 1 calculate the tasks
*HW responsibilities
	*tab1 hf57 hf58 hf59 hf60 hf61 hf62
gen refpers_sex=sex if relarp==1
	replace refpers_sex=sex_p if relarp==2
	replace refpers_sex=sex_p if relarp==3
	replace refpers_sex=0 if refpers_sex==1
	replace refpers_sex=1 if refpers_sex==2
	label var refpers_sex "Sex of the reference person"
	label define sex1 0 "Man" 1 "Woman"
	label values refpers_sex sex1

gen hw_meals=.
	replace hw_meals=1 if hf57==1 & refpers_sex==0
	replace hw_meals=1 if hf57==2 & refpers_sex==1
	replace hw_meals=2 if hf57==3
	replace	hw_meals=3 if hf57==1 & refpers_sex==1
	replace	hw_meals=3 if hf57==2 & refpers_sex==0
	replace hw_meals=4 if inlist(hf57, 4,5,6,7,8)
	label var hw_meals "Responsibilities for making meals"
	label define hw_resp 1 "Man more" 2 "Equal" 3 "Woman more" 4"Other solution"
	label values hw_meals hw_resp

gen hw_cleaning=.
	replace hw_cleaning=1 if hf58==1 & refpers_sex==0
	replace hw_cleaning=1 if hf58==2 & refpers_sex==1
	replace hw_cleaning=2 if hf58==3
	replace	hw_cleaning=3 if hf58==1 & refpers_sex==1
	replace	hw_cleaning=3 if hf58==2 & refpers_sex==0
	replace hw_cleaning=4 if inlist(hf58, 4,5,6,7,8)
	label var hw_cleaning "Responsibilities for cleaning, tidying"
	label values hw_cleaning hw_resp

gen hw_shopping=.
	replace hw_shopping=1 if hf59==1 & refpers_sex==0
	replace hw_shopping=1 if hf59==2 & refpers_sex==1
	replace hw_shopping=2 if hf59==3
	replace	hw_shopping=3 if hf59==1 & refpers_sex==1
	replace	hw_shopping=3 if hf59==2 & refpers_sex==0
	replace hw_shopping=4 if inlist(hf59, 4,5,6,7,8)
	label var hw_shopping "Responsibilities for shopping"
	label values hw_shopping hw_resp

gen hw_washing=.
	replace hw_washing=1 if hf60==1 & refpers_sex==0
	replace hw_washing=1 if hf60==2 & refpers_sex==1
	replace hw_washing=2 if hf60==3
	replace	hw_washing=3 if hf60==1 & refpers_sex==1
	replace	hw_washing=3 if hf60==2 & refpers_sex==0
	replace hw_washing=4 if inlist(hf60, 4,5,6,7,8)
	label var hw_washing "Responsibilities for washing, ironing"
	label values hw_washing hw_resp

//gendered division of housework tasks 
	tab hw_meals, gen(hw_meals)
	tab hw_cleaning, gen(hw_cleaning)
	tab hw_shopping, gen(hw_shopping)
	tab hw_washing, gen(hw_washing)
	
	g hw_meals_mi=1 	if hw_meals==.
	g hw_cleaning_mi=1 	if hw_cleaning==.
	g hw_shopping_mi=1 	if hw_shopping==.
	g hw_washing_mi=1 	if hw_washing==.
	
egen hw4_resp_mi=rowtotal(hw_meals_mi hw_cleaning_mi hw_shopping_mi hw_washing_mi)
	
foreach var of varlist hw_meals hw_cleaning hw_shopping hw_washing { 
gen `var'_2=`var'
replace `var'_2=2 if `var'==4
label values `var'_2 hw_resp
todummies `var'_2
}

egen hw_resp_w=rowtotal(hw_meals_23 hw_cleaning_23 hw_shopping_23 hw_washing_23)
replace hw_resp_w=. if hw4_resp_mi==4
egen hw_resp_m=rowtotal(hw_meals_21 hw_cleaning_21 hw_shopping_21 hw_washing_21)
replace hw_resp_m=. if hw4_resp_mi==4
egen hw_resp_e=rowtotal(hw_meals_22 hw_cleaning_22 hw_shopping_22 hw_washing_22)
replace hw_resp_e=. if hw4_resp_mi==4

egen hw_resp_m2	=rowtotal(hw_resp_m hw_resp_m hw_resp_e)
replace hw_resp_m2=. if hw4_resp_mi==4
egen hw_resp_w2	=rowtotal(hw_resp_w hw_resp_w hw_resp_e)
replace hw_resp_w2=. if hw4_resp_mi==4

gen hw_resp_perc=hw_resp_w2/(hw_resp_w2+hw_resp_m2)*100 if hw_resp_w2+hw_resp_m2!=0
replace hw_resp_perc=50 if hw_resp_w2+hw_resp_m2==0
label variable hw_resp_perc "Woman's share of housework (in %)"


*Step 2: weekly hours and tasks
gen hwhours60=hwhours
replace hwhours60=60 if hwhours>60 & hwhours!=.
gen hwhours60_p=hwhours_p
replace hwhours60_p=60 if hwhours_p>60 & hwhours_p!=.

gen hw60_c=hwhours60+hwhours60_p

gen 	hw60_perc1=hwhours60/(hwhours60+hwhours60_p)*100 
replace hw60_perc1=50 if 	hw60_c==0

gen hw60_perc=hw60_perc1
replace hw60_perc=hw_resp_perc if hw60_perc1==.
label variable hw60_perc "Woman's share of housework (in %)"

gen hw60_perc_3cat=1 		if 	hw60_perc<45
replace hw60_perc_3cat=2 	if 	hw60_perc>=45 & hw60_perc<=55
replace hw60_perc_3cat=3 	if 	hw60_perc>55  & hw60_perc!=. 
label variable hw60_perc_3cat "Couple's housework arrangement"
label values hw60_perc_3cat m_w_ratio

recode hw60_perc_3cat (3=0 "Doing gender, woman more") (1/2=1 "Undoing gender, equal or man more"), gen(hw60_perc_2cat)

	
**# Bookmark #5
*--------------------------------------------------------------------
* Couple's childcare arrangement
*--------------------------------------------------------------------

// due to various problems at individual answers of weekly hours, for chilcare we begin by the division of tasks, and follow with hours

*relying on tasks
//CC responsibilities 
//if child/ren less than 15 years old
//Regarding the children in your household, can you tell me who usually takes care of the following tasks?
	*tab1 hf53 hf54 hf55 hf56
	
gen cc_play=.
	replace cc_play=1 if hf54==1 & refpers_sex==0
	replace cc_play=1 if hf54==2 & refpers_sex==1
	replace cc_play=2 if hf54==3
	replace	cc_play=3 if hf54==1 & refpers_sex==1
	replace	cc_play=3 if hf54==2 & refpers_sex==0
	replace cc_play=4 if inlist(hf54, 4,5,6,7,8,9,10)
	replace cc_play=2 if inlist(hf54, 11)
	label var cc_play "Childcare: playing with them"
	label values cc_play hw_resp
	
gen cc_school=.
	replace cc_school=1 if hf55==1 & refpers_sex==0
	replace cc_school=1 if hf55==2 & refpers_sex==1
	replace cc_school=2 if hf55==3
	replace	cc_school=3 if hf55==1 & refpers_sex==1
	replace	cc_school=3 if hf55==2 & refpers_sex==0
	replace cc_school=4 if inlist(hf55, 4,5,6,7,8,9,10)
	replace cc_school=2 if inlist(hf55, 11)
	label var cc_school "Childcare: taking them to school"
	label values cc_school hw_resp
	
gen cc_homework=.
	replace cc_homework=1 if hf56==1 & refpers_sex==0
	replace cc_homework=1 if hf56==2 & refpers_sex==1
	replace cc_homework=2 if hf56==3
	replace	cc_homework=3 if hf56==1 & refpers_sex==1
	replace	cc_homework=3 if hf56==2 & refpers_sex==0
	replace cc_homework=4 if inlist(hf56, 4,5,6,7,8,9,10)
	replace cc_homework=2 if inlist(hf56, 11)
	label var cc_homework "Childcare: help with homework"
	label values cc_homework hw_resp
	
replace cc_play=.		if idhous==47162
replace cc_school=.		if idhous==47162	
replace cc_homework=.	if idhous==47162

//gendered division of childcare tasks
	tab cc_play, gen(cc_play)
	tab cc_school, gen(cc_school)
	tab cc_homework, gen(cc_homework)
	
	g cc_play_mi			=1 	if cc_play==.
	g cc_school_mi			=1 	if cc_school==.
	g cc_homework_mi		=1 	if cc_homework==.
	
egen cc_resp_mi=rowtotal(cc_play_mi cc_school_mi cc_homework_mi)

foreach var of varlist cc_play cc_school cc_homework { 
gen `var'_2=`var'
replace `var'_2=2 if `var'==4
label values `var'_2 hw_resp
todummies `var'_2
}

egen cc_resp_w=rowtotal(cc_play_23 cc_school_23 cc_homework_23)
replace cc_resp_w=. if cc_resp_mi==3
egen cc_resp_m=rowtotal(cc_play_21 cc_school_21 cc_homework_21)
replace cc_resp_m=. if cc_resp_mi==3
egen cc_resp_e=rowtotal (cc_play_22 cc_school_22 cc_homework_22)
replace cc_resp_e=. if cc_resp_mi==3	
	
egen cc_resp_m2	=rowtotal(cc_resp_m cc_resp_m cc_resp_e)
replace cc_resp_m2=. if cc_resp_mi==3
egen cc_resp_w2	=rowtotal(cc_resp_w cc_resp_w cc_resp_e)
replace cc_resp_w2=. if cc_resp_mi==3	
	
gen cct_perc=cc_resp_w2/(cc_resp_w2+cc_resp_m2)*100
replace cct_perc=50 if cc_resp_w2+cc_resp_m2==0
label variable cct_perc "Woman's share of childcare (tasks, in %)"

gen cct_perc_3cat=1 		if 	cct_perc<45
replace cct_perc_3cat=2 	if 	cct_perc>=45 & cct_perc<=55
replace cct_perc_3cat=3 	if 	cct_perc>55  & cct_perc!=. 
label variable cct_perc_3cat "Couple's childcare arrangement (percent)"
label values cct_perc_3cat m_w_ratio

recode cct_perc_3cat (3=0 "Doing gender, woman more") (1/2=1 "Undoing gender, equal or man more"), gen(cct_perc_2cat)



**# Bookmark #6
*--------------------------------------------------------------------
* Couple's unpaid work arrangement (i.e., household work and childcare tasks)
*--------------------------------------------------------------------

gen hwcc60_perc=(hw60_perc+cct_perc)/2
replace hwcc60_perc=hw60_perc if hwcc60_perc==.
replace hwcc60_perc=cct_perc if hwcc60_perc==.
label variable hwcc60_perc "Woman's share of unpaid work (in %)"

gen hwcc60_perc_rev= (hwcc60_perc-100)*(-1) // same as above
label variable hwcc60_perc_rev "Man's share of unpaid work (in %)"

*45-55%
gen hwcc60_perc_3cat=1 		if 	hwcc60_perc<45
replace hwcc60_perc_3cat=2 	if 	hwcc60_perc>=45 & hwcc60_perc<=55
replace hwcc60_perc_3cat=3 	if 	hwcc60_perc>55  & hwcc60_perc!=. 
label variable hwcc60_perc_3cat "Couple's unpaid work arrangement (percent)"
label values hwcc60_perc_3cat m_w_ratio

recode hwcc60_perc_3cat (3=0 "Doing gender, woman more") (1/2=1 "Undoing gender, equal or man more"), gen(hwcc60_perc_2cat)



**# Bookmark #7
*--------------------------------------------------------------------
* Couple's educational level
*--------------------------------------------------------------------
gen edu_c=edu3_p-edu3

recode edu_c (1/3=0 "Man more") (-3/0=1 "Equal or woman more"), gen(edu_c2cat)
label variable edu_c2cat "Couple's education"



**# Bookmark #8
*--------------------------------------------------------------------
* Couple's annual income
*--------------------------------------------------------------------

*Proportion of female income in the couple: 45-55%
gen prop_inc=incomei/(incomei+incomei_p)
label var prop_inc "Proportion of female income in the couple"

gen inc_perc=prop_inc*100
label variable inc_perc "Couple's income share (percent)"

gen inc_perc_3cat2=1 		if 	inc_perc<45
replace inc_perc_3cat2=2 	if 	inc_perc>=45 & inc_perc<=55
replace inc_perc_3cat2=3 	if 	inc_perc>55  & inc_perc!=. 
label variable inc_perc_3cat2 "Couple's income share"
label values inc_perc_3cat2 m_w_ratio

recode inc_perc_3cat2 (1=0 "Man more") (2/3=1 "Equal or woman more"), gen(inc_perc_2cat2)
label variable inc_perc_2cat2 "Couple's income share"

recode inc_perc_2cat2 (0=0 "Man more") (1=1 "Equal or woman more") (.=2 "Missing"), gen(inc_perc_2cat2mi)
label variable inc_perc_2cat2mi "Couple's income share"


compress 

save "${mydata}\shp_couple_hetero_1864_all_variables", replace
log close


